@@ -26,6 +26,8 @@
 #include <QComboBox>
 #include <QGridLayout>
 #include <QLabel>
+#include <QRandomGenerator>
+#include <QRegularExpression>
 #include <QStringList>
 #include <QWidget>
 #include "Common.h"
@@ -61,6 +63,7 @@ bool ChoiceParameter::addTo(QWidget * widget, int row)
   _comboBox->setCurrentIndex(_value);
 
   _grid->addWidget(_label = new QLabel(_name, widget), row, 0, 1, 1);
+  setTextSelectable(_label);
   _grid->addWidget(_comboBox, row, 1, 1, 2);
   connectComboBox();
   return true;
@@ -102,13 +105,23 @@ void ChoiceParameter::reset()
   connectComboBox();
 }
 
-bool ChoiceParameter::initFromText(const char * text, int & textLength)
+void ChoiceParameter::randomize()
+{
+  if (acceptRandom()) {
+    disconnectComboBox();
+    _value = QRandomGenerator::global()->bounded(0, _comboBox->count());
+    _comboBox->setCurrentIndex(_value);
+    connectComboBox();
+  }
+}
+
+bool ChoiceParameter::initFromText(const QString & filterName, const char * text, int & textLength)
 {
   QStringList list = parseText("choice", text, textLength);
   if (list.isEmpty()) {
     return false;
   }
-  _name = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0]));
+  _name = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0], filterName));
   _choices = list[1].split(QChar(','));
   bool ok;
   if (_choices.isEmpty()) {
@@ -122,8 +135,8 @@ bool ChoiceParameter::initFromText(const char * text, int & textLength)
   }
   QList<QString>::iterator it = _choices.begin();
   while (it != _choices.end()) {
-    *it = it->trimmed().remove(QRegExp("^\"")).remove(QRegExp("\"$"));
-    *it = HtmlTranslator::html2txt(FilterTextTranslator::translate(*it));
+    *it = it->trimmed().remove(QRegularExpression("^\"")).remove(QRegularExpression("\"$"));
+    *it = HtmlTranslator::html2txt(FilterTextTranslator::translate(*it, filterName));
     ++it;
   }
   _value = _default;
@@ -141,7 +154,7 @@ void ChoiceParameter::connectComboBox()
   if (_connected) {
     return;
   }
-  connect(_comboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(onComboBoxIndexChanged(int)));
+  connect(_comboBox, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &ChoiceParameter::onComboBoxIndexChanged);
   _connected = true;
 }
 
